@@ -4,6 +4,12 @@ import copy
 from ..lib.customer import find_usecase
 from django.apps import AppConfig
 
+def get_default_configuration():
+    return """
+    This app requires low code configuration implemented using the app
+    sdk or other means. Please get in touch with the platform manager.
+    """
+
 class EnrichAppConfig(AppConfig):
 
     name="default"
@@ -17,6 +23,8 @@ class EnrichAppConfig(AppConfig):
     entry = "index"
     tags = ["store"]
     _readme = ""
+    _configuration = ""
+    _resources = ""
 
     @property
     def readme(cls):
@@ -27,6 +35,24 @@ class EnrichAppConfig(AppConfig):
         else:
             return cls._readme
 
+    @property
+    def configuration(cls):
+        if hasattr(cls, 'get_configuration'):
+            return cls.get_configuration()
+        elif cls._configuration == "":
+            return get_default_configuration()
+        else:
+            return cls._configuration
+
+    @property
+    def resources(cls):
+        if hasattr(cls, 'get_resources'):
+            return cls.get_resources()
+        elif cls._resources == "":
+            return get_default_resources()
+        else:
+            return cls._resources
+
     def get_usecase(self):
 
         if self.filename is None:
