@@ -6,7 +6,9 @@ import sys
 import copy
 import yaml
 import json
+import logging
 
+logger = logging.getLogger()
 
 class Context:
     def __init__(self, config=None, *args, **kwargs):
@@ -38,12 +40,12 @@ class Context:
         # => Priority yaml config -> environment variables..
         # Root has to be specified
         if "ENRICH_ROOT" not in self.context:
-            if "ENRICH_ROOT" not in os.environ:
-                raise Exception(
-                    "ENRICH_ROOT must be specified in context file or environment"
-                )
-            else:
+            if "ENRICH_ROOT" in os.environ:
                 self.context["ENRICH_ROOT"] = os.environ["ENRICH_ROOT"]
+            else:
+                logger.warning(
+                    "ENRICH_ROOT must ideally be specified in context file or environment. Using default /tmp/enrich")
+                self.context['ENRICH_ROOT'] = os.environ['ENRICH_ROOT'] = '/tmp/enrich'
 
         defaults = {
             "ENRICH_RUN_ROOT": "%(ENRICH_ROOT)s",
