@@ -43,7 +43,6 @@ from .log import setup_logging
 from .mock import *
 from ..lib import *
 from ..lib.customer import load_customer_assets
-from ..app.flask.render import create_app
 from enrichsdk.tasks import Task
 from enrichsdk.core.res import set_limits
 
@@ -99,10 +98,9 @@ def welcome():
     print("==============================")
     print("  Welcome to Scribble Enrich ")
     print("=============================")
-    print("\n")
 
 
-def read_conf():
+def read_conf(create=True):
 
     # Created a global configuration
     confpath = "enrich.json"
@@ -116,6 +114,12 @@ def read_conf():
             traceback.print_exc()
             pass
 
+    if not create:
+         print(
+             "enrich.json is missing but continuing"
+         )
+         return {}
+
     print(
         "First we have to create a configuration file (enrich.json). After we update you"
     )
@@ -239,11 +243,12 @@ def load_enrichjson_defaults(target, usecase=True):
     defaults = {}
 
     if usecase:
-        enrichjsons = glob2.glob(target + "/../*/enrich.json") + glob2.glob(
-            target + "/../*enrich.json"
-        )
+        enrichjsons = glob2.glob(target + "/../*/enrich.json") + \
+                              glob2.glob(target + "/../*enrich.json")
     else:
-        enrichjsons = glob2.glob(target + "/*enrich.json")
+        enrichjsons = glob2.glob(target + "/*enrich.json") + \
+                              glob2.glob(target + "/../*enrich.json") + \
+                              glob2.glob(target + "/../../*enrich.json")
 
         # Initialize
         defaults["org_name"] = os.path.basename(os.path.abspath(target))
@@ -469,6 +474,44 @@ def prepare_dashboard(target, templatepath):
     )
 
 
+def prepare_module_generic(target, templatepath, what):
+    """
+    Bootstrap a generic module template..
+    """
+
+    if templatepath is None:
+        templatepath = get_template_path(what)
+
+    try:
+        os.makedirs(target)
+    except:
+        pass
+
+    defaults = load_enrichjson_defaults(target, usecase=False)
+
+    transform_root = get_template_path("metrics")
+
+    context = {}
+
+    # First copy the py files
+    files = glob2.glob(transform_root + "/**")
+    for f in files:
+        if f.endswith("~") or f == "__pycache__":
+            continue
+        content = open(f).read()
+        variables = get_variables(f)
+
+        for v in variables:
+            context[v] = prompt(
+                "> " + v + ": ",
+                default=defaults.get(v, ""))
+        basename = os.path.basename(f)
+
+        # Write a local copy
+        write_rendered_file(f, target, basename, context)
+        print(greenbg(basename))
+
+
 def prepare_asset(what, target, templatepath):
 
     print("Bootstrapping a {}".format(what))
@@ -481,7 +524,7 @@ def prepare_asset(what, target, templatepath):
     if os.path.exists(target):
         raise Exception("Target directory exists. Please remove it")
 
-    conf = read_conf()
+    conf = read_conf(create=False)
 
     # Create setup.py etc.
     prepare_setup(what, target)
@@ -642,7 +685,7 @@ def prepare_tasklib(path, templatepath):
 
     print("Bootstrapping a new task library\n")
 
-    conf = read_conf()
+    conf = read_conf(create=False)
 
     validators = {"name": NameValidator(), "description": GenericDescValidator()}
 
@@ -677,7 +720,7 @@ def prepare_taskconf(path, templatepath):
 
     print("Bootstrapping a new task configuration file\n")
 
-    conf = read_conf()
+    conf = read_conf(create=False)
 
     if not path.lower().endswith(".json"):
         print("Task configuration file should be a json")
@@ -790,7 +833,7 @@ def prepare_script_default(path, templatepath):
     if os.path.exists(path):
         raise Exception("Output path already exists. Please remove it")
 
-    conf = read_conf()
+    conf = read_conf(create=False)
 
     validators = {
         "confname": NameValidator(),
@@ -836,7 +879,7 @@ def prepare_script_minimal(path, templatepath):
         raise Exception("Output path already exists. Please remove it")
 
     try:
-        conf = read_conf()
+        conf = read_conf(create=False)
     except:
         conf = {}
 
@@ -890,8 +933,6 @@ def prepare_rscript(path, templatepath):
 
     welcome()
 
-    print("Bootstrapping an R Script\n")
-
     if not path.lower().endswith(".r"):
         print("R script should end with .r/R")
         return
@@ -908,8 +949,6 @@ def prepare_pyscript(path, templatepath):
 
     welcome()
 
-    print("Bootstrapping an Python Script\n")
-
     if not path.lower().endswith(".py"):
         print("py script should end with .py")
         return
@@ -921,6 +960,24 @@ def prepare_pyscript(path, templatepath):
 
     prepare_script_default(path, lib_template)
 
+def prepare_datasets(path, templatepath):
+
+    welcome()
+
+    if not path.lower().endswith(".py"):
+        print("datasets should end with .py")
+        return
+
+    if templatepath is None:
+        lib_template = get_template_path("datasets.py.template")
+    else:
+        lib_template = templatepath
+
+    prepare_script_default(path, lib_template)
+
+    print("""Please make sure you go through the file and update the paths as appropriate""")
+
+
 
 def prepare_transform_script(path, templatepath, what="simpletransform"):
 
@@ -1064,6 +1121,8 @@ def bootstrap(component, path, templatepath):
         prepare_transform_script(path, templatepath, what="helloworld")
     elif component in ["transform-query"]:
         prepare_transform_script(path, templatepath, what="query")
+    elif component in ["transform-metrics"]:
+        prepare_module_generic(path, templatepath, "metrics")
     elif component in ["transform-iris"]:
         prepare_transform_script(path, templatepath, what="iris")
     # elif component == 'model':
@@ -1096,6 +1155,8 @@ def bootstrap(component, path, templatepath):
         prepare_rscript(path, templatepath)
     elif component in ["pyscript"]:
         prepare_pyscript(path, templatepath)
+    elif component in ["datasets"]:
+        prepare_datasets(path, templatepath)
 
 
 def get_sample_siteconf():
