@@ -21,12 +21,14 @@ from kafka.admin import KafkaAdminClient, NewTopic
 logger = logging.getLogger("kafka")
 logger.setLevel(logging.CRITICAL)
 
+
 class MessagingBase(object):
     """
     Base class to handle the interfacing with various messaging
     backends.
 
     """
+
     def __init__(self, config, *args, **kwargs):
         """
         Initialize the messaging object
@@ -81,6 +83,7 @@ class MessagingBase(object):
     def stop(self):
         pass
 
+
 class PyKafkaMessaging(MessagingBase):
     """
 
@@ -108,26 +111,24 @@ class PyKafkaMessaging(MessagingBase):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        if 'hosts' not in self.config:
+        if "hosts" not in self.config:
             raise Exception("Kafka hosts must be specified")
 
     def connect(self):
-        hosts = self.config.get('hosts')
+        hosts = self.config.get("hosts")
         hosts = ",".join(hosts)
         self.client = KafkaClient(hosts=hosts)
 
     def produce(self, topic, callback, params):
         topic = self.client.topics[topic]
-        producer_params = self.config.get('produce_params',{})
+        producer_params = self.config.get("produce_params", {})
         with topic.get_sync_producer(**producer_params) as producer:
             for data in callback(params):
-                producer.produce(json.dumps(data).encode('utf-8'))
-
-
+                producer.produce(json.dumps(data).encode("utf-8"))
 
     def consume(self, topic, callback, params):
         topic = self.client.topics[topic]
-        consume_params = self.config.get('consume_params',{})
+        consume_params = self.config.get("consume_params", {})
         balanced_consumer = topic.get_balanced_consumer(**consume_params)
         try:
             for message in balanced_consumer:
@@ -139,26 +140,26 @@ class PyKafkaMessaging(MessagingBase):
         finally:
             balanced_consumer.stop()
 
-class KafkaMessaging(MessagingBase):
 
+class KafkaMessaging(MessagingBase):
     def topics(self):
         consumer = KafkaConsumer(**self.config)
         available = consumer.topics()
         consumer.close()
         return available
 
-    def create_topic(self, topic, partitions=1,replication_factor=1):
+    def create_topic(self, topic, partitions=1, replication_factor=1):
         admin_client = KafkaAdminClient(**self.config)
 
         topic_list = []
         topic_list.append(NewTopic(name=topic, num_partitions=1, replication_factor=1))
         admin_client.create_topics(new_topics=topic_list, validate_only=False)
 
-
     def produce(self, topic, callback, params={}):
 
-        producer = KafkaProducer(value_serializer=lambda v: json.dumps(v).encode('utf-8'),
-                             **self.config)
+        producer = KafkaProducer(
+            value_serializer=lambda v: json.dumps(v).encode("utf-8"), **self.config
+        )
 
         try:
             if callable(callback):
@@ -166,16 +167,17 @@ class KafkaMessaging(MessagingBase):
                     producer.send(topic, data)
             else:
                 data = callback
-                producer.send(topic,data)
+                producer.send(topic, data)
         finally:
             producer.close()
 
-
     def consume(self, topic, callback, params):
 
-        consumer = KafkaConsumer(topic,
-                                 value_deserializer=lambda v: json.loads(v.decode('utf-8')),
-                                 **self.config)
+        consumer = KafkaConsumer(
+            topic,
+            value_deserializer=lambda v: json.loads(v.decode("utf-8")),
+            **self.config
+        )
 
         try:
             for msg in consumer:
