@@ -11,16 +11,18 @@ pipeline. They are called workflows here to avoid confusion with
 import traceback
 import logging
 
-logger = logging.getLogger('app')
+logger = logging.getLogger("app")
 
 from .transforms import TransformBase
 
+
 class State(object):
     """
     Internal state objects. Transform classes use this
     state object to store and retrieve state during
     execution.
     """
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.frames = {}
@@ -34,6 +36,7 @@ class State(object):
     def dumps(self):
         return str(self.frames.keys())
 
+
 class WorkflowBase(object):
     """
     Base class to define a workflow. This class registers new
@@ -41,11 +44,11 @@ class WorkflowBase(object):
     support DAGs in future.
 
     """
+
     def __init__(self, *args, **kwargs):
-        """
-        """
-        self.config = kwargs.get('config', {})
-        self.debug = kwargs.get('debug', False)
+        """ """
+        self.config = kwargs.get("config", {})
+        self.debug = kwargs.get("debug", False)
         self.transforms = []
         self.logger = logging.getLogger()
 
@@ -54,18 +57,20 @@ class WorkflowBase(object):
         if not isinstance(specs, list):
             raise Exception("Add expects a list of specifications")
 
-        globalargs = self.config.get('args', {})
+        globalargs = self.config.get("args", {})
 
         for index, spec in enumerate(specs):
 
             if issubclass(spec, TransformBase):
                 transform = spec
-                name = spec.__name__ # class
+                name = spec.__name__  # class
             elif isinstance(spec, dict):
-                if 'transform' not in spec:
-                    raise Exception("Spec dictionary should include a 'transform' class")
-                transform = spec['transform']
-                name = spec.get('name', transform.name)
+                if "transform" not in spec:
+                    raise Exception(
+                        "Spec dictionary should include a 'transform' class"
+                    )
+                transform = spec["transform"]
+                name = spec.get("name", transform.name)
             else:
                 raise Exception(f"Unexpected data type {type(spec)}")
 
@@ -73,9 +78,9 @@ class WorkflowBase(object):
             t = transform(**kwargs)
 
             # Configure it with the new args...
-            args = globalargs.get(name,{})
-            args['name'] = name
-            t.configure(pipeline=self,args=args)
+            args = globalargs.get(name, {})
+            args["name"] = name
+            t.configure(pipeline=self, args=args)
 
             # Do any other initialization such as connecting to the
             # database..
@@ -92,7 +97,7 @@ class WorkflowBase(object):
         """
 
         state = State()
-        state.put('streamrow', streamrow)
+        state.put("streamrow", streamrow)
 
         for t in self.transforms:
             try:
@@ -112,10 +117,5 @@ class WorkflowBase(object):
         extra = {}
         if self.debug:
             versions = [str(t) for t in self.transforms]
-            extra = {
-                'versions': versions
-            }
+            extra = {"versions": versions}
         return extra
-
-
-
