@@ -356,11 +356,13 @@ def init_(component, path, template, context):
         ["transform-simple", "A transform structured as a python module"],
         ["transform-helloworld", "A simple hello world transform for study"],
         ["transform-query", "A  transform that uses a pre-existing database querying module"],
+        ["transform-metrics", "A  transform that uses a pre-existing metrics module"],
         ["transform-iris", "Simple Iris post-processing example"],
         ["asset", "A reusable library "],
         ["dashboard", "A django app that fits the Enrich Dashboard framework"],
         ["pipeline", "A pipeline configuration"],
         ["prefectjob", "Prefect workflow template"],
+        ["datasets", "Datasets specification file"],
         ["rscript", "R-Script template"],
         ["pyscript", "A python script template"]
     ]
@@ -1414,3 +1416,6 @@ process.add_command(_show_log)
 
 def main():
     process()
+
+if __name__ == "__main__":
+    main()
