@@ -11,8 +11,10 @@ from dateutil import relativedelta
 from celery.utils.log import get_task_logger
 
 from django.db import connections
+
 logger = get_task_logger(__name__)
 
+
 @shared_task(name="complex_task")
 def complex_task(params):
     """
@@ -20,19 +22,11 @@ def complex_task(params):
     """
 
     try:
-        records = [
-            {
-                'name': 'John',
-                'location': "South Africa"
-            }
-        ]
+        records = [{"name": "John", "location": "South Africa"}]
 
         logger.info(f"Received {len(records) -1} records")
     except:
         logger.exception("Error while executing the query")
         raise
 
-    return {
-        'records': records
-    }
-
+    return {"records": records}
