@@ -16,7 +16,7 @@ register_app_instance(
     urlpatterns=urlpatterns,
     spec=customspec,
     app_urlpatterns=[
-        url('^[/]?$', views.index, name="index"),
+        url(r'^[/]?$', views.index, name="index"),
     ]
 )
 
