@@ -1,5 +1,6 @@
 import json
 from sqllineage.runner import LineageRunner
+from datetime import date, datetime
 
 from .sample import *
 
@@ -90,7 +91,7 @@ def note(df, title):
     msg += "--------" + "\n"
     msg += "Timestamp: " + str(datetime.now()) + "\n"
     msg += "\nShape: " + str(df.shape) + "\n"
-    msg += "\nColumns: " + ", ".join(df.columns) + "\n"
+    msg += "\nColumns: " + ", ".join([str(c) for c in df.columns]) + "\n"
     if len(df) > 0:
         msg += "\nSample:" + "\n"
         msg += df.sample(min(2, len(df))).T.to_string() + "\n" + "\n"
@@ -98,3 +99,19 @@ def note(df, title):
     msg += df.dtypes.to_string() + "\n"
     msg += "------" + "\n"
     return msg
+
+############################
+
+def get_month():
+    return datetime.utcnow().strftime("%Y-%m")
+
+def get_yesterday():
+    yesterday = date.today() + timedelta(days=-1)
+    return yesterday.isoformat()
+
+def get_tomorrow():
+    tomorrow = date.today() + timedelta(days=1)
+    return tomorrow.isoformat()
+
+def get_today():
+    return date.today().isoformat()
