@@ -28,6 +28,7 @@ def bulk_get_data(cache, keys):
 
     return data
 
+
 def bulk_get_keys(cache, pattern, chunk_size=5000):
     """
     Get the keys...
@@ -36,11 +37,9 @@ def bulk_get_keys(cache, pattern, chunk_size=5000):
     """
 
     allkeys = []
-    cursor = '0'
+    cursor = "0"
     while cursor != 0:
-        cursor, keys = cache.scan(cursor=cursor,
-                                  match=pattern,
-                                  count=chunk_size)
+        cursor, keys = cache.scan(cursor=cursor, match=pattern, count=chunk_size)
         if keys:
             allkeys.extend(keys)
 
@@ -55,17 +54,16 @@ def clear(cache, pattern, chunk_size=5000):
     """
 
     count = 0
-    cursor = '0'
+    cursor = "0"
     while cursor != 0:
-        cursor, keys = cache.scan(cursor=cursor,
-                                  match=pattern,
-                                  count=chunk_size)
+        cursor, keys = cache.scan(cursor=cursor, match=pattern, count=chunk_size)
         if keys:
             count += len(keys)
             cache.delete(*keys)
 
     return count
 
+
 def clear_atomic(cache, pattern):
     """
     Clears a namespace in redis cache.
@@ -82,10 +80,8 @@ def clear_atomic(cache, pattern):
 
     return count
 
-def write_records_atomic(cache, records,
-                         keygenerator,
-                         spec,
-                         expiry=7*86400):
+
+def write_records_atomic(cache, records, keygenerator, spec, expiry=7 * 86400):
     """
     Serialize and write records
 
@@ -101,9 +97,9 @@ def write_records_atomic(cache, records,
     found = defaultdict(int)
     stats = defaultdict(int)
 
-    exclude = spec.get('exclude', []) #what columns to exclude
-    suffix = spec.get('suffix', "") # add bits to the key name
-    target = spec.get('target','map') # what is the target
+    exclude = spec.get("exclude", [])  # what columns to exclude
+    suffix = spec.get("suffix", "")  # add bits to the key name
+    target = spec.get("target", "map")  # what is the target
 
     # Make sure we know what action to do.
     # map = store a dict
@@ -111,8 +107,7 @@ def write_records_atomic(cache, records,
     # elements = store individual elements
     # elements-serialized = store individual elements but serialize them..
     #
-    if target not in ['map', 'map-serialized',
-                      'elements', 'elements-serialized']:
+    if target not in ["map", "map-serialized", "elements", "elements-serialized"]:
         raise Exception(f"Unknown target: {target}")
 
     if not isinstance(exclude, list):
@@ -132,25 +127,25 @@ def write_records_atomic(cache, records,
                 raise Exception("Unknown key generator")
 
             # What are the available columns?
-            columns = spec.get('columns', list(r.keys()))
+            columns = spec.get("columns", list(r.keys()))
 
             # What should I exclude?
             columns = [c for c in columns if c not in exclude]
 
             # Get what I should write
-            towrite = {k: v for k,v in r.items() if k in columns}
+            towrite = {k: v for k, v in r.items() if k in columns}
 
             if len(towrite) == 0:
-                stats['error-empty'] += 1
+                stats["error-empty"] += 1
                 continue
 
             # Handle the simple cases...
-            if spec['target'] in ['map', 'map-serialized']:
+            if spec["target"] in ["map", "map-serialized"]:
                 key += suffix
                 if key in found:
-                    stats['duplicates'] += 1
+                    stats["duplicates"] += 1
                     continue
-                if target == 'map-serialized': # serialize
+                if target == "map-serialized":  # serialize
                     value = pickle.dumps(towrite)
                     pipe.set(key + "_pickled", value)
                 else:
@@ -161,38 +156,40 @@ def write_records_atomic(cache, records,
                 if expiry > 0:
                     pipe.expire(key, expiry)
 
-                stats['valid'] +=1
+                stats["valid"] += 1
                 continue
 
             # Handle the list case...
-            if spec['target'] in ['elements', 'elements-serialized']:
+            if spec["target"] in ["elements", "elements-serialized"]:
                 for col in list(towrite.keys()):
                     colkey = f"{key}:{col}{suffix}"
                     # Have we seen this key?
                     if colkey in found:
-                        stats['duplicates'] += 1
+                        stats["duplicates"] += 1
                         continue
 
                     value = towrite[col]
 
                     # We now have to set the list...
-                    if target == 'elements-serialized':
+                    if target == "elements-serialized":
                         value = pickle.dumps(value)
                         pipe.set(colkey + "_pickled", value)
                     elif isinstance(value, list):
-                        pipe.delete(colkey)# clear all elements
+                        pipe.delete(colkey)  # clear all elements
                         pipe.rpush(colkey, *value)
                     elif isinstance(value, dict):
                         pipe.hmset(colkey, value)
                     else:
-                        raise Exception(f"Unknown element type {type(value)} for {colkey}")
+                        raise Exception(
+                            f"Unknown element type {type(value)} for {colkey}"
+                        )
 
                     found[colkey] += 1
-                    stats['valid'] +=1
+                    stats["valid"] += 1
 
         except Exception as e:
-            stats['error'] +=1
-            stats['message'] = str(e)
+            stats["error"] += 1
+            stats["message"] = str(e)
             break
 
         count += 1
@@ -201,10 +198,8 @@ def write_records_atomic(cache, records,
 
     return dict(stats)
 
-def write_df_dict(cache, df,
-                  keygenerator,
-                  spec,
-                  expiry=7*86400):
+
+def write_df_dict(cache, df, keygenerator, spec, expiry=7 * 86400):
     """
     Serialize and write dataframe
 
@@ -238,9 +233,6 @@ def write_df_dict(cache, df,
     """
 
     # Generate records
-    records = df.to_dict('records')
+    records = df.to_dict("records")
 
-    return write_records_atomic(cache, records,
-                                keygenerator,
-                                spec,
-                                expiry)
+    return write_records_atomic(cache, records, keygenerator, spec, expiry)
